<?php

namespace App\Wrangler\Components;

use Illuminate\Http\Request;
use Medialight\Textstem\Helpers\MediaAsset;
use Medialight\Textstem\Models\WranglerPage;
use Medialight\Textstem\Wrangler\ActiveComponent;

class CarouselSlide extends ActiveComponent
{
    public static string $description = 'Displays a slide in a carousel.';

    public $config;

    public array $editSetup = [
        [
            'name' => 'title',
            'controltype' => 'text',
            'value' => '',
            'label' => 'Title',
            'instructions' => 'Optional title. Note - this text will be escaped. To enter raw HTML, use the HTML block.',
        ],
        [
            'name' => 'content',
            'controltype' => 'richtext',
            'value' => '',
            'label' => 'Content',
        ],
        [
            'name' => 'image',
            'controltype' => 'image',
            'value' => '',
            'label' => "Image (Desktop)",
            'aspect' => '16/6',
            'size' => 3
        ],
        [
            'name' => 'imagemobile',
            'controltype' => 'image',
            'value' => '',
            'label' => "Image (Mobile)",
            'aspect' => 'square',
            'size' => 1
        ],
        [
            'name' => 'link',
            'controltype' => 'text',
            'value' => '',
            'label' => 'Link',
            'size' => 4
        ],
//        [
//            'name' => 'link2',
//            'controltype' => 'text',
//            'value' => '',
//            'label' => 'Secondary Link',
//            'size' =>2
//        ],
        [
            'name' => 'template',
            'controltype' => 'select-template',
            'value' => 'default',
        ],
    ];

    public function render(Request $request, WranglerPage $wranglerPage)
    {
        $view = $this->getView();
        $viewData = $this->data();
        $viewData['asset'] = MediaAsset::loadForPath($this->config['image'] ?? '');
        $imagemobile = empty($this->config['imagemobile']) ? ($this->config['image'] ?? '') : $this->config['imagemobile'];
        $viewData['assetmobile'] = MediaAsset::loadForPath($imagemobile); //dd($viewData);
        return view($view, $viewData)->render();
    }

    public function preview()
    {
        $view = $this->getPreview();
        $viewData = $this->data();
        $viewData['asset'] = MediaAsset::loadForPath($this->config['image'] ?? '');
        $imagemobile = empty($this->config['imagemobile']) ? ($this->config['image'] ?? '') : $this->config['imagemobile'];
        $viewData['assetmobile'] = MediaAsset::loadForPath($imagemobile);
        return view($view, $viewData)->render();
    }
}
